==> fuse.js-5.0.0-beta.tgz: package/README.md <==
<p align="center"><a href="https://fusejs.io" target="_blank" rel="noopener noreferrer"><img width="200" src="https://fusejs.io/assets/images/logo.png" alt="Fuse.js logo"></a></p>

<p align="center">
  <img src="https://github.com/krisk/Fuse/workflows/Node.js%20CI/badge.svg" alt="Node.js CI"/>
  <a href="https://www.npmjs.com/package/fuse.js"><img src="https://img.shields.io/npm/v/fuse.js.svg" alt="Version"/></a>
  <a href="https://npmcharts.com/compare/fuse.js?minimal=true"><img src="https://img.shields.io/npm/dm/fuse.js.svg" alt="Downloads" /></a>
    <a href="https://github.com/krisk/Fuse/graphs/contributors"><img src="https://img.shields.io/github/contributors/krisk/fuse.svg" alt="Contributors" /></a>
  <a href="https://www.npmjs.com/package/fuse.js"><img src="https://img.shields.io/npm/l/fuse.js.svg" alt="License"></a>
<!--   <a href="https://discord.gg/QF4B9sf"><img src="https://img.shields.io/badge/chat-on%20discord-7289da.svg" alt="Chat"></a> -->
</p>

## <!--special end-->

#### _What's new in v5.0.0-beta_

- _Added ability to search patterns longer longer than 32 characters_
- _Added [enhanced searching](https://fusejs.io/#extended-search)_

---

## Introduction

Fuse.js is a lightweight fuzzy-search, in JavaScript, with zero dependencies.

## Documentation

To checkout out live examples and docs, visit [fusejs.io](https://fusejs.io).

## Installation

**NPM**

```sh
# latest
$ npm install --save fuse.js
```

## Contributing

### Coding conventions

Code should be run through [Standard Format](https://www.npmjs.com/package/standard-format).

### Testing

Before submitting a pull request, please add the relevant tests in the `test/` directory, and execute them via `npm test`.

==> fuse.js-5.0.1-beta.tgz: package/README.md <==
<p align="center"><a href="https://fusejs.io" target="_blank" rel="noopener noreferrer"><img width="200" src="https://fusejs.io/assets/images/logo.png" alt="Fuse.js logo"></a></p>

<p align="center">
  <img src="https://github.com/krisk/Fuse/workflows/Node.js%20CI/badge.svg" alt="Node.js CI"/>
  <a href="https://www.npmjs.com/package/fuse.js"><img src="https://img.shields.io/npm/v/fuse.js.svg" alt="Version"/></a>
  <a href="https://npmcharts.com/compare/fuse.js?minimal=true"><img src="https://img.shields.io/npm/dm/fuse.js.svg" alt="Downloads" /></a>
    <a href="https://github.com/krisk/Fuse/graphs/contributors"><img src="https://img.shields.io/github/contributors/krisk/fuse.svg" alt="Contributors" /></a>
  <a href="https://www.npmjs.com/package/fuse.js"><img src="https://img.shields.io/npm/l/fuse.js.svg" alt="License"></a>
<!--   <a href="https://discord.gg/QF4B9sf"><img src="https://img.shields.io/badge/chat-on%20discord-7289da.svg" alt="Chat"></a> -->
</p>

## <!--special end-->

#### _What's new in v5 (beta)_

- _Added ability to search patterns longer than 32 characters_
- _Added [enhanced searching](https://fusejs.io/#extended-search)_

---

## Introduction

Fuse.js is a lightweight fuzzy-search, in JavaScript, with zero dependencies.

## Documentation

To checkout out live examples and docs, visit [fusejs.io](https://fusejs.io).

## Installation

**NPM**

```sh
# latest
$ npm install --save fuse.js
```

## Contributing

### Coding conventions

Code should be run through [Standard Format](https://www.npmjs.com/package/standard-format).

### Testing

Before submitting a pull request, please add the relevant tests in the `test/` directory, and execute them via `npm test`.
